@@ -45,7 +45,8 @@ def test_clean_env_install(bare_virtualenv, tmp_src):
     """
     Check setuptools can be installed in a clean environment.
     """
-    bare_virtualenv.run(['python', 'setup.py', 'install'], cd=tmp_src)
+    cmd = [bare_virtualenv.python, 'setup.py', 'install']
+    bare_virtualenv.run(cmd, cd=tmp_src)
 
 
 def _get_pip_versions():
@@ -74,18 +75,10 @@ def _get_pip_versions():
     def skip_network(param):
         return param if network else mark(param, pytest.mark.skip(reason="no network"))
 
-    issue2599 = pytest.mark.skipif(
-        sys.version_info > (3, 10),
-        reason="pypa/setuptools#2599",
-    )
-
     network_versions = [
-        mark('pip==9.0.3', issue2599),
-        mark('pip==10.0.1', issue2599),
-        mark('pip==18.1', issue2599),
         mark('pip==19.3.1', pytest.mark.xfail(reason='pypa/pip#6599')),
         'pip==20.0.2',
-        'https://github.com/pypa/pip/archive/master.zip',
+        'https://github.com/pypa/pip/archive/main.zip',
     ]
 
     versions = itertools.chain(
@@ -203,5 +196,5 @@ def test_no_missing_dependencies(bare_virtualenv, request):
     Quick and dirty test to ensure all external dependencies are vendored.
     """
     for command in ('upload',):  # sorted(distutils.command.__all__):
-        cmd = ['python', 'setup.py', command, '-h']
+        cmd = [bare_virtualenv.python, 'setup.py', command, '-h']
         bare_virtualenv.run(cmd, cd=request.config.rootdir)
